@@ -9,6 +9,12 @@ from blackcap.schemas.metrics import Metrics
 class BaseObserver(ABC):
     """Base Observer class."""
 
+    CONFIG_KEY = "OBSERVER"
+    CONFIG_KEY_DEF_VAL = "ELASTIC"
+
+    # Change this value in custom auther implementations.
+    CONFIG_KEY_VAL = "ELASTIC"
+
     @abstractclassmethod
     def get_metrics(self: "BaseObserver", range: str) -> List[Metrics]:  # noqa: E501
         """Get cluster metrics.
